@@ -1,6 +1,17 @@
 ## ------------------------------------------------------------------------------------------------|
-# Data generator according to the graph structure
+#     Copyright (C) 2012 - 2018  Reza Mohammadi                                                    |
+#                                                                                                  |
+#     This file is part of BDgraph package.                                                        |
+#                                                                                                  |
+#     BDgraph is free software: you can redistribute it and/or modify it under                     |
+#     the terms of the GNU General Public License as published by the Free                         |
+#     Software Foundation; see <https://cran.r-project.org/web/licenses/GPL-3>.                    |
+#                                                                                                  |
+#     Maintainer: Reza Mohammadi <a.mohammadi@uva.nl>                                              |
 ## ------------------------------------------------------------------------------------------------|
+#     Data generator according to the graph structure                                              |
+## ------------------------------------------------------------------------------------------------|
+
 bdgraph.sim = function( p = 10, graph = "random", n = 0, type = "Gaussian", 
 						prob = 0.2, size = NULL, mean = 0, class = NULL, 
 						cut = 4, b = 3, D = diag(p), K = NULL, sigma = NULL, 
@@ -17,153 +28,37 @@ bdgraph.sim = function( p = 10, graph = "random", n = 0, type = "Gaussian",
 	    graph <- "fixed"
     } 
 	
-#--- build the graph structure --------------------------------------------------------------------|
-	if( graph == "random" )
-	{
-		G <- matrix( 0, p, p )
-
-		if( is.null( size ) )
-		{
-#			if( prob < 0 | prob > 1 ) stop( "'prob' must be between zero and one" )
-			
-			G[ upper.tri( G ) ] <- rbinom( p * ( p - 1 ) / 2, 1, prob )
-		} 
-		else 
-		{
-			if( size < 0 | size > p * ( p - 1 ) / 2 )  stop( "Graph size must be between zero and p*(p-1)/2" )
-			
-			smp <- sample( 1 : ( p * ( p - 1 ) / 2 ), size, replace = FALSE )
-			G[ upper.tri( G ) ][smp] <- 1
-		}
-		
-		G <- G + t( G )
-	}
-	
-	if( graph == "cluster" )
-	{
-		# partition variables
-		if( is.null( class ) )
-		{ 
-			class = NULL
-			if( !is.null( size ) )   class = length( size )
-			if( length( prob ) > 1 ) class = length( prob )
-			if( is.null( class ) )   class = max( 2, ceiling( p / 20 ) )
-
-			if( !is.null( size ) )
-			{
-				class <- length( size )
-			}else{
-				class <- max( 2, ceiling( p / 20 ) )
-			}
-		}
-
-		g.large <- p %% class
-		g.small <- class - g.large
-		n.small <- floor( p / class )
-		n.large <- n.small + 1
-		vp      <- c( rep( n.small, g.small ), rep( n.large, g.large ) )
-		 
-		G       <- matrix( 0, p, p )
-		 
-		if( is.null( size ) )
-		{
-#			if( prob < 0 | prob > 1 ) stop( "'prob' must be between zero and one" )
-
-			for( i in 1 : class )
-			{
-				tmp <- if( i == 1 ) ( 1 : vp[1] ) else ( ( sum( vp[1 : (i-1)] ) + 1 ) : sum( vp[1:i] ) )
-				gg                <- matrix( 0, vp[i], vp[i] )
-				gg[upper.tri(gg)] <- rbinom( vp[i] * ( vp[i] - 1 ) / 2, 1, prob )
-				G[tmp, tmp]       <- gg
-			}
-		} 
-		else 
-		{
-			if( class != length(size) )  stop( "Number of graph sizes is not match with number of clusters" )
-			if( sum(size) < 0 | sum(size) > p * (p - 1) / 2 )   stop( "Total graph sizes must be between zero and p*(p-1)/2" )
-
-			for( i in 1 : class )
-			{
-				tmp <- if( i == 1 ) ( 1 : vp[1] ) else ( ( sum( vp[1 : (i-1)] ) + 1 ) : sum( vp[1:i] ) )
-				gg  <- matrix( 0, vp[i], vp[i] )
-				smp <- sample( 1 : ( vp[i] * (vp[i] - 1) / 2 ), size[i], replace = FALSE )
-				gg[upper.tri(gg)][smp] <- 1
-				G[tmp, tmp]            <- gg
-			}
-		}
-		
-		G <- G + t(G)	   
+    #--- build the graph structure ----------------------------------------------------------------|
+    if( sum( graph != c( "fixed", "AR1", "AR2", "star" ) ) == 0 )
+    {
+		G <- BDgraph::graph.sim( p = p, graph = graph, prob = prob, size = size, class = class, vis = vis )
 	}
 
-	if( graph == "hub" )
-	{
-		# partition variables
-		if( is.null( class ) ) class <- ceiling( p / 20 ) 
-
-		# partition variables into groups
-		g.large <- p %% class
-		g.small <- class - g.large
-		n.small <- floor( p / class )
-		n.large <- n.small + 1
-		g.list  <- c( rep( n.small, g.small ), rep( n.large, g.large ) )
-		g.ind   <- rep( c( 1:class ), g.list )
-		
-		G <- matrix( 0, p, p )
-		
-		for( i in 1:class )
-		{
-			tmp           <- which( g.ind == i )
-			G[tmp[1],tmp] <- 1
-			G[tmp,tmp[1]] <- 1
-		}
-	}
-	
-	if( graph == "circle" )
-	{
-	    G       <- toeplitz( c( 0, 1, rep( 0, p - 2 ) ) )
-        G[1, p] <- 1
-		G[p, 1] <- 1
-	}
-
-	if( graph == "scale-free" )
-	{
-		G = matrix( 0, p, p )
-		resultGraph = .C( "scale_free", G = as.integer(G), as.integer(p), PACKAGE = "BDgraph" )
-		G = matrix( resultGraph $ G, p, p ) 
-		
-		j = sample( 1:p, 1 )
-		
-		for( i in ( c( 1:p )[ -j ] ) )
-		{
-			 G[ i, j ] = 1
-			 G[ j, i ] = 1
-		}
-	}
-	
-	if( graph == "AR1" )
-	{
-		sigma = matrix( 0, p, p )
-		for (i in 1 : (p - 1))
-			for (j in (i + 1) : p)
-				sigma[i, j] = ( 0.7 ) ^ abs( i - j )
-	
-		sigma = sigma + t( sigma ) + diag( p )
-		K     = solve( sigma )
-		G     = 1 * ( abs(K) > 0.2 ) 
-	}
-
-	if( graph == "AR2" )
-	{
-		K = toeplitz( c( 1, 0.5, 0.25, rep( 0, p - 3 ) ) )
-		G = 1 * ( abs(K) > 0.2 ) 
-	}
-
-	if( graph == "star" )
-	{
-		K                 <- diag(p)
-		K[ 1, ( 2 : p ) ] <- 0.1
-		K[ ( 2 : p ), 1 ] <- 0.1
-	}
+    if( graph == "AR1" )
+    {
+        sigma = matrix( 0, p, p )
+        
+        for (i in 1 : (p - 1))
+            for (j in (i + 1) : p)
+                sigma[i, j] = ( 0.7 ) ^ abs( i - j )
+            
+            sigma = sigma + t( sigma ) + diag( p )
+            K     = solve( sigma )
+            #G     = 1 * ( abs(K) > 0.2 ) 
+    }
+    
+    if( graph == "AR2" )
+    {
+        K = toeplitz( c( 1, 0.5, 0.25, rep( 0, p - 3 ) ) )
+        # G = 1 * ( abs(K) > 0.2 ) 
+    }
+    
+    if( graph == "star" )
+    {
+        K                 <- diag(p)
+        K[ 1, ( 2 : p ) ] <- 0.1
+        K[ ( 2 : p ), 1 ] <- 0.1
+    }
 
 	#--- generate multivariate data according to the graph structure ------------------------------|
 	if( n != 0 )
@@ -184,17 +79,13 @@ bdgraph.sim = function( p = 10, graph = "random", n = 0, type = "Gaussian",
 			result = .C( "rgwish_c", as.integer(G), as.double(Ti), K = as.double(K), 
 						 as.integer(b), as.integer(p), PACKAGE = "BDgraph" )
 			
-			K     = matrix ( result $ K, p, p ) 		
+			K     = matrix( result $ K, p, p ) 		
 			sigma = solve( K )
 		}
 		
 		#--- generate multivariate normal data ----------------------------------------------------|
-		if( typeof( mean ) == "double" ) mean <- rep( mean, p )
-		R <- chol( sigma )
-		z <- matrix( rnorm( p * n ), p, n )
-		d <- t( R ) %*% z + mean
-		d <- t( d )
-
+		d <- BDgraph::rmvnorm( n = n, mean = mean, sigma = sigma )
+		
 		#--- generate multivariate mixed data -----------------------------------------------------|
 		if( type == "mixed" )
 		{
@@ -260,16 +151,6 @@ bdgraph.sim = function( p = 10, graph = "random", n = 0, type = "Gaussian",
 		}
 	}
 	
-	#--- graph visualization ----------------------------------------------------------------------|
-	if( vis )
-	{
-		graphG <- graph.adjacency( G, mode = "undirected", diag = FALSE )
-		
-		if( p < 20 ) size = 10 else size = 2
-		plot.igraph( graphG, layout = layout.circle, main = "Graph structure", 
-		             vertex.color = "white", vertex.size = size, vertex.label.color = 'black' )
-	}
-	
 	#--- Saving the result ------------------------------------------------------------------------|
 	if( n != 0 )
 	{
